diff libpurple/protocols/msn/msg.c @ 15822:32c366eeeb99

sed -ie 's/gaim/purple/g'
author Sean Egan <seanegan@gmail.com>
date Mon, 19 Mar 2007 07:01:17 +0000
parents 5fe8042783c1
children 44b4e8bd759b 60bc06498746 4a099e4d0d09
line wrap: on
line diff
--- a/libpurple/protocols/msn/msg.c	Mon Mar 19 06:11:46 2007 +0000
+++ b/libpurple/protocols/msn/msg.c	Mon Mar 19 07:01:17 2007 +0000
@@ -1,9 +1,9 @@
 /**
  * @file msg.c Message functions
  *
- * gaim
+ * purple
  *
  * Gaim is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.
  *
@@ -33,7 +33,7 @@
 	msg->type = type;
 
 #ifdef MSN_DEBUG_MSG
-	gaim_debug_info("msn", "message new (%p)(%d)\n", msg, type);
+	purple_debug_info("msn", "message new (%p)(%d)\n", msg, type);
 #endif
 
 	msg->attr_table = g_hash_table_new_full(g_str_hash, g_str_equal,
@@ -57,7 +57,7 @@
 	}
 
 #ifdef MSN_DEBUG_MSG
-	gaim_debug_info("msn", "message destroy (%p)\n", msg);
+	purple_debug_info("msn", "message destroy (%p)\n", msg);
 #endif
 
 	if (msg->remote_user != NULL)
@@ -86,7 +86,7 @@
 	msg->ref_count++;
 
 #ifdef MSN_DEBUG_MSG
-	gaim_debug_info("msn", "message ref (%p)[%d]\n", msg, msg->ref_count);
+	purple_debug_info("msn", "message ref (%p)[%d]\n", msg, msg->ref_count);
 #endif
 
 	return msg;
@@ -101,7 +101,7 @@
 	msg->ref_count--;
 
 #ifdef MSN_DEBUG_MSG
-	gaim_debug_info("msn", "message unref (%p)[%d]\n", msg, msg->ref_count);
+	purple_debug_info("msn", "message unref (%p)[%d]\n", msg, msg->ref_count);
 #endif
 
 	if (msg->ref_count == 0)
@@ -128,7 +128,7 @@
 	msn_message_set_attr(msg, "X-MMS-IM-Format",
 						 "FN=MS%20Sans%20Serif; EF=; CO=0; PF=0");
 
-	message_cr = gaim_str_add_cr(message);
+	message_cr = purple_str_add_cr(message);
 	msn_message_set_bin_data(msg, message_cr, strlen(message_cr));
 	g_free(message_cr);
 
@@ -781,7 +781,7 @@
 		}
 	}
 
-	gaim_debug_info("msn", "Message %s:\n{%s}\n", info, str->str);
+	purple_debug_info("msn", "Message %s:\n{%s}\n", info, str->str);
 
 	g_string_free(str, TRUE);
 }
@@ -1,9 +1,9 @@
  *
- * Gaim is the legal property of its developers, whose names are too numerous
+ * Purple is the legal property of its developers, whose names are too numerous
  * to list here.  Please refer to the COPYRIGHT file distributed with this
  * source distribution.